@@ -20,6 +20,7 @@
 
 #include "cli/TextStream.h"
 #include "core/Database.h"
+#include "core/EntryAttributes.h"
 #include "keys/CompositeKey.h"
 #include "keys/FileKey.h"
 #include "keys/PasswordKey.h"
@@ -27,24 +28,32 @@
 
 namespace Utils
 {
-    extern FILE* STDOUT;
-    extern FILE* STDERR;
-    extern FILE* STDIN;
-    extern FILE* DEVNULL;
+    extern QTextStream STDOUT;
+    extern QTextStream STDERR;
+    extern QTextStream STDIN;
+    extern QTextStream DEVNULL;
+
+    void setDefaultTextStreams();
 
     void setStdinEcho(bool enable);
-    QString getPassword(FILE* outputDescriptor = STDOUT);
+    QString getPassword(bool quiet = false);
+    QSharedPointer<PasswordKey> getConfirmedPassword();
     int clipText(const QString& text);
     QSharedPointer<Database> unlockDatabase(const QString& databaseFilename,
                                             const bool isPasswordProtected = true,
                                             const QString& keyFilename = {},
-                                            FILE* outputDescriptor = STDOUT,
-                                            FILE* errorDescriptor = STDERR);
+                                            const QString& yubiKeySlot = {},
+                                            bool quiet = false);
 
-    namespace Test
-    {
-        void setNextPassword(const QString& password);
-    }
+    QStringList splitCommandString(const QString& command);
+
+    /**
+     * If `attributes` contains an attribute named `name` (case-sensitive),
+     * returns a list containing only `name`. Otherwise, returns the list of
+     * all attribute names in `attributes` matching the given name
+     * (case-insensitive).
+     */
+    QStringList findAttributes(const EntryAttributes& attributes, const QString& name);
 }; // namespace Utils
 
 #endif // KEEPASSXC_UTILS_H
