@@ -36,9 +36,6 @@ const int Group::DefaultIconNumber = 48;
 const int Group::RecycleBinIconNumber = 43;
 const QString Group::RootAutoTypeSequence = "{USERNAME}{TAB}{PASSWORD}{ENTER}";
 
-Group::CloneFlags Group::DefaultCloneFlags =
-    Group::CloneNewUuid | Group::CloneResetTimeInfo | Group::CloneIncludeEntries;
-
 Group::Group()
     : m_customData(new CustomData(this))
     , m_updateTimeinfo(true)
