@@ -21,37 +21,40 @@
 #include <QTextStream>
 #include <cmath>
 
-#include "core/FilePath.h"
+#include "core/Resources.h"
 #include "crypto/Random.h"
 
 const char* PassphraseGenerator::DefaultSeparator = " ";
 const char* PassphraseGenerator::DefaultWordList = "eff_large.wordlist";
 
 PassphraseGenerator::PassphraseGenerator()
-    : m_wordCount(0)
-    , m_separator(PassphraseGenerator::DefaultSeparator)
+    : m_wordCount(DefaultWordCount)
+    , m_wordCase(LOWERCASE)
+    , m_separator(DefaultSeparator)
 {
+    setDefaultWordList();
 }
 
-double PassphraseGenerator::calculateEntropy(const QString& passphrase)
+double PassphraseGenerator::estimateEntropy(int wordCount)
 {
-    Q_UNUSED(passphrase);
-
     if (m_wordlist.isEmpty()) {
         return 0.0;
     }
+    if (wordCount < 1) {
+        wordCount = m_wordCount;
+    }
 
-    return std::log2(m_wordlist.size()) * m_wordCount;
+    return std::log2(m_wordlist.size()) * wordCount;
 }
 
 void PassphraseGenerator::setWordCount(int wordCount)
 {
-    if (wordCount > 0) {
-        m_wordCount = wordCount;
-    } else {
-        // safe default if something goes wrong
-        m_wordCount = DefaultWordCount;
-    }
+    m_wordCount = qMax(1, wordCount);
+}
+
+void PassphraseGenerator::setWordCase(PassphraseWordCase wordCase)
+{
+    m_wordCase = wordCase;
 }
 
 void PassphraseGenerator::setWordList(const QString& path)
@@ -77,7 +80,7 @@ void PassphraseGenerator::setWordList(const QString& path)
 
 void PassphraseGenerator::setDefaultWordList()
 {
-    const QString path = filePath()->wordlistPath(PassphraseGenerator::DefaultWordList);
+    const QString path = resources()->wordlistPath(PassphraseGenerator::DefaultWordList);
     setWordList(path);
 }
 
@@ -88,6 +91,7 @@ void PassphraseGenerator::setWordSeparator(const QString& separator)
 
 QString PassphraseGenerator::generatePassphrase() const
 {
+    QString tmpWord;
     Q_ASSERT(isValid());
 
     // In case there was an error loading the wordlist
@@ -98,7 +102,22 @@ QString PassphraseGenerator::generatePassphrase() const
     QStringList words;
     for (int i = 0; i < m_wordCount; ++i) {
         int wordIndex = randomGen()->randomUInt(static_cast<quint32>(m_wordlist.length()));
-        words.append(m_wordlist.at(wordIndex));
+        tmpWord = m_wordlist.at(wordIndex);
+
+        // convert case
+        switch (m_wordCase) {
+        case UPPERCASE:
+            tmpWord = tmpWord.toUpper();
+            break;
+        case TITLECASE:
+            tmpWord = tmpWord.replace(0, 1, tmpWord.left(1).toUpper());
+            break;
+        case LOWERCASE:
+        default:
+            tmpWord = tmpWord.toLower();
+            break;
+        }
+        words.append(tmpWord);
     }
 
     return words.join(m_separator);
