@@ -24,19 +24,21 @@
 
 #include "ScreenLockListenerPrivate.h"
 
-class ScreenLockListenerMac: public ScreenLockListenerPrivate {
+class ScreenLockListenerMac : public ScreenLockListenerPrivate
+{
     Q_OBJECT
 
 public:
     static ScreenLockListenerMac* instance();
-    static void notificationCenterCallBack(CFNotificationCenterRef center, void* observer,
-                                           CFStringRef name, const void* object,
+    static void notificationCenterCallBack(CFNotificationCenterRef center,
+                                           void* observer,
+                                           CFStringRef name,
+                                           const void* object,
                                            CFDictionaryRef userInfo);
 
 private:
     ScreenLockListenerMac(QWidget* parent = nullptr);
     void onSignalReception();
-
 };
 
 #endif // SCREENLOCKLISTENERMAC_H
