@@ -29,8 +29,8 @@
  * a 256-bit salt is generated each time the database is saved, the tag length is 256 bits, no secret key
  * or associated data. KeePass uses the latest version of Argon2, v1.3.
  */
-Argon2Kdf::Argon2Kdf()
-    : Kdf::Kdf(KeePass2::KDF_ARGON2)
+Argon2Kdf::Argon2Kdf(Type type)
+    : Kdf::Kdf(type == Type::Argon2d ? KeePass2::KDF_ARGON2D : KeePass2::KDF_ARGON2ID)
     , m_version(0x13)
     , m_memory(1 << 16)
     , m_parallelism(static_cast<quint32>(QThread::idealThreadCount()))
@@ -54,6 +54,11 @@ bool Argon2Kdf::setVersion(quint32 version)
     return false;
 }
 
+Argon2Kdf::Type Argon2Kdf::type() const
+{
+    return uuid() == KeePass2::KDF_ARGON2D ? Type::Argon2d : Type::Argon2id;
+}
+
 quint64 Argon2Kdf::memory() const
 {
     return m_memory;
@@ -133,7 +138,7 @@ bool Argon2Kdf::processParameters(const QVariantMap& p)
 QVariantMap Argon2Kdf::writeParameters()
 {
     QVariantMap p;
-    p.insert(KeePass2::KDFPARAM_UUID, KeePass2::KDF_ARGON2.toRfc4122());
+    p.insert(KeePass2::KDFPARAM_UUID, uuid().toRfc4122());
     p.insert(KeePass2::KDFPARAM_ARGON2_VERSION, version());
     p.insert(KeePass2::KDFPARAM_ARGON2_PARALLELISM, parallelism());
     p.insert(KeePass2::KDFPARAM_ARGON2_MEMORY, memory() * 1024);
@@ -158,18 +163,20 @@ bool Argon2Kdf::transform(const QByteArray& raw, QByteArray& result) const
 {
     result.clear();
     result.resize(32);
-    return transformKeyRaw(raw, seed(), version(), rounds(), memory(), parallelism(), result);
+    return transformKeyRaw(raw, seed(), version(), type(), rounds(), memory(), parallelism(), result);
 }
 
 bool Argon2Kdf::transformKeyRaw(const QByteArray& key,
                                 const QByteArray& seed,
                                 quint32 version,
+                                Type type,
                                 quint32 rounds,
                                 quint64 memory,
                                 quint32 parallelism,
                                 QByteArray& result)
 {
     // Time Cost, Mem Cost, Threads/Lanes, Password, length, Salt, length, out, length
+
     int rc = argon2_hash(rounds,
                          memory,
                          parallelism,
@@ -181,7 +188,7 @@ bool Argon2Kdf::transformKeyRaw(const QByteArray& key,
                          result.size(),
                          nullptr,
                          0,
-                         Argon2_d,
+                         type == Type::Argon2d ? Argon2_d : Argon2_id,
                          version);
     if (rc != ARGON2_OK) {
         qWarning("Argon2 error: %s", argon2_error_message(rc));
@@ -205,7 +212,7 @@ int Argon2Kdf::benchmarkImpl(int msec) const
     timer.start();
 
     int rounds = 4;
-    if (transformKeyRaw(key, seed, version(), rounds, memory(), parallelism(), key)) {
+    if (transformKeyRaw(key, seed, version(), type(), rounds, memory(), parallelism(), key)) {
         return static_cast<int>(rounds * (static_cast<float>(msec) / timer.elapsed()));
     }
 
@@ -214,5 +221,6 @@ int Argon2Kdf::benchmarkImpl(int msec) const
 
 QString Argon2Kdf::toString() const
 {
-    return QObject::tr("Argon2 (%1 rounds, %2 KB)").arg(QString::number(rounds()), QString::number(memory()));
+    return QObject::tr("Argon2%1 (%2 rounds, %3 KB)")
+        .arg(type() == Type::Argon2d ? "d" : "id", QString::number(rounds()), QString::number(memory()));
 }
