@@ -23,7 +23,13 @@
 class Argon2Kdf : public Kdf
 {
 public:
-    Argon2Kdf();
+    enum class Type
+    {
+        Argon2d,
+        Argon2id
+    };
+
+    Argon2Kdf(Type type);
 
     bool processParameters(const QVariantMap& p) override;
     QVariantMap writeParameters() override;
@@ -32,6 +38,7 @@ public:
 
     quint32 version() const;
     bool setVersion(quint32 version);
+    Type type() const;
     quint64 memory() const;
     bool setMemory(quint64 kibibytes);
     quint32 parallelism() const;
@@ -49,6 +56,7 @@ private:
     Q_REQUIRED_RESULT static bool transformKeyRaw(const QByteArray& key,
                                                   const QByteArray& seed,
                                                   quint32 version,
+                                                  Type type,
                                                   quint32 rounds,
                                                   quint64 memory,
                                                   quint32 parallelism,
