@@ -31,6 +31,8 @@ class OSEventFilter;
 class QLockFile;
 class QSocketNotifier;
 
+constexpr int RESTART_EXITCODE = -1;
+
 class Application : public QApplication
 {
     Q_OBJECT
@@ -39,10 +41,16 @@ public:
     Application(int& argc, char** argv);
     ~Application() override;
 
+    void applyTheme();
+
     bool event(QEvent* event) override;
     bool isAlreadyRunning() const;
+    bool isDarkTheme() const;
 
     bool sendFileNamesToRunningInstance(const QStringList& fileNames);
+    bool sendLockToInstance();
+
+    void restart();
 
 signals:
     void openFile(const QString& filename);
@@ -68,6 +76,7 @@ private:
     static int unixSignalSocket[2];
 #endif
     bool m_alreadyRunning;
+    bool m_darkTheme = false;
     QLockFile* m_lockFile;
     QLocalServer m_lockServer;
     QString m_socketName;
@@ -76,4 +85,6 @@ private:
 #endif
 };
 
+#define kpxcApp qobject_cast<Application*>(Application::instance())
+
 #endif // KEEPASSX_APPLICATION_H
