@@ -250,8 +250,12 @@ void ApplicationSettingsWidget::loadSettings()
     }
 
     m_generalUi->trayIconAppearance->clear();
+#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+    m_generalUi->trayIconAppearance->addItem(tr("Monochrome"), "monochrome");
+#else
     m_generalUi->trayIconAppearance->addItem(tr("Monochrome (light)"), "monochrome-light");
     m_generalUi->trayIconAppearance->addItem(tr("Monochrome (dark)"), "monochrome-dark");
+#endif
     m_generalUi->trayIconAppearance->addItem(tr("Colorful"), "colorful");
     int trayIconIndex = m_generalUi->trayIconAppearance->findData(resources()->trayIconAppearance());
     if (trayIconIndex > 0) {
