@@ -41,7 +41,7 @@
 #include "gui/entry/EntryView.h"
 #include "gui/group/GroupView.h"
 #ifdef Q_OS_MACOS
-#include "gui/macutils/MacUtils.h"
+#include "gui/osutils/macutils/MacUtils.h"
 #endif
 #include "gui/wizard/NewDatabaseWizard.h"
 
@@ -49,7 +49,7 @@ DatabaseTabWidget::DatabaseTabWidget(QWidget* parent)
     : QTabWidget(parent)
     , m_dbWidgetStateSync(new DatabaseWidgetStateSync(this))
     , m_dbWidgetPendingLock(nullptr)
-    , m_databaseOpenDialog(new DatabaseOpenDialog())
+    , m_databaseOpenDialog(new DatabaseOpenDialog(this))
 {
     auto* tabBar = new DragTabBar(this);
     setTabBar(tabBar);
@@ -80,8 +80,10 @@ void DatabaseTabWidget::toggleTabbar()
 {
     if (count() > 1) {
         tabBar()->show();
+        emit tabVisibilityChanged(true);
     } else {
         tabBar()->hide();
+        emit tabVisibilityChanged(false);
     }
 }
 
@@ -273,7 +275,11 @@ void DatabaseTabWidget::importKeePass1Database()
 
 void DatabaseTabWidget::importOpVaultDatabase()
 {
-    QString fileName = fileDialog()->getExistingDirectory(this, "Open .opvault database");
+#ifdef Q_OS_MACOS
+    QString fileName = fileDialog()->getOpenFileName(this, tr("Open OPVault"), {}, "OPVault (*.opvault)");
+#else
+    QString fileName = fileDialog()->getExistingDirectory(this, tr("Open OPVault"));
+#endif
 
     if (fileName.isEmpty()) {
         return;
@@ -351,13 +357,17 @@ bool DatabaseTabWidget::closeDatabaseTab(DatabaseWidget* dbWidget)
  */
 bool DatabaseTabWidget::closeAllDatabaseTabs()
 {
-    while (count() > 0) {
-        if (!closeDatabaseTab(0)) {
-            return false;
+    // Attempt to lock all databases first to prevent closing only a portion of tabs
+    if (lockDatabases()) {
+        while (count() > 0) {
+            if (!closeDatabaseTab(0)) {
+                return false;
+            }
         }
+        return true;
     }
 
-    return true;
+    return false;
 }
 
 bool DatabaseTabWidget::saveDatabase(int index)
@@ -383,6 +393,20 @@ bool DatabaseTabWidget::saveDatabaseAs(int index)
     return ok;
 }
 
+bool DatabaseTabWidget::saveDatabaseBackup(int index)
+{
+    if (index == -1) {
+        index = currentIndex();
+    }
+
+    auto* dbWidget = databaseWidgetFromIndex(index);
+    bool ok = dbWidget->saveBackup();
+    if (ok) {
+        updateLastDatabases(dbWidget->database()->filePath());
+    }
+    return ok;
+}
+
 void DatabaseTabWidget::closeDatabaseFromSender()
 {
     auto* dbWidget = qobject_cast<DatabaseWidget*>(sender());
@@ -452,12 +476,17 @@ bool DatabaseTabWidget::warnOnExport()
     return ans == MessageBox::Yes;
 }
 
-void DatabaseTabWidget::changeMasterKey()
+void DatabaseTabWidget::showDatabaseSecurity()
 {
-    currentDatabaseWidget()->switchToMasterKeyChange();
+    currentDatabaseWidget()->switchToDatabaseSecurity();
 }
 
-void DatabaseTabWidget::changeDatabaseSettings()
+void DatabaseTabWidget::showDatabaseReports()
+{
+    currentDatabaseWidget()->switchToDatabaseReports();
+}
+
+void DatabaseTabWidget::showDatabaseSettings()
 {
     currentDatabaseWidget()->switchToDatabaseSettings();
 }
@@ -590,15 +619,27 @@ DatabaseWidget* DatabaseTabWidget::currentDatabaseWidget()
     return qobject_cast<DatabaseWidget*>(currentWidget());
 }
 
-void DatabaseTabWidget::lockDatabases()
+/**
+ * Attempt to lock all open databases
+ *
+ * @return return true if all databases are locked
+ */
+bool DatabaseTabWidget::lockDatabases()
 {
-    for (int i = 0, c = count(); i < c; ++i) {
+    int numLocked = 0;
+    int c = count();
+    for (int i = 0; i < c; ++i) {
         auto dbWidget = databaseWidgetFromIndex(i);
-        if (dbWidget->lock() && dbWidget->database()->filePath().isEmpty()) {
-            // If we locked a database without a file close the tab
-            closeDatabaseTab(dbWidget);
+        if (dbWidget->lock()) {
+            ++numLocked;
+            if (dbWidget->database()->filePath().isEmpty()) {
+                // If we locked a database without a file close the tab
+                closeDatabaseTab(dbWidget);
+            }
         }
     }
+
+    return numLocked == c;
 }
 
 /**
@@ -645,11 +686,11 @@ void DatabaseTabWidget::unlockDatabaseInDialog(DatabaseWidget* dbWidget,
  */
 void DatabaseTabWidget::relockPendingDatabase()
 {
-    if (!m_dbWidgetPendingLock || !config()->get("security/relockautotype").toBool()) {
+    if (!m_dbWidgetPendingLock || !config()->get(Config::Security_RelockAutoType).toBool()) {
         return;
     }
 
-    if (m_dbWidgetPendingLock->isLocked() || !m_dbWidgetPendingLock->database()->hasKey()) {
+    if (m_dbWidgetPendingLock->isLocked() || !m_dbWidgetPendingLock->database()->isInitialized()) {
         m_dbWidgetPendingLock = nullptr;
         return;
     }
@@ -660,17 +701,17 @@ void DatabaseTabWidget::relockPendingDatabase()
 
 void DatabaseTabWidget::updateLastDatabases(const QString& filename)
 {
-    if (!config()->get("RememberLastDatabases").toBool()) {
-        config()->set("LastDatabases", QVariant());
+    if (!config()->get(Config::RememberLastDatabases).toBool()) {
+        config()->remove(Config::LastDatabases);
     } else {
-        QStringList lastDatabases = config()->get("LastDatabases", QVariant()).toStringList();
+        QStringList lastDatabases = config()->get(Config::LastDatabases).toStringList();
         lastDatabases.prepend(filename);
         lastDatabases.removeDuplicates();
 
-        while (lastDatabases.count() > config()->get("NumberOfRememberedLastDatabases").toInt()) {
+        while (lastDatabases.count() > config()->get(Config::NumberOfRememberedLastDatabases).toInt()) {
             lastDatabases.removeLast();
         }
-        config()->set("LastDatabases", lastDatabases);
+        config()->set(Config::LastDatabases, lastDatabases);
     }
 }
 
@@ -709,9 +750,17 @@ void DatabaseTabWidget::performGlobalAutoType()
     if (!unlockedDatabases.isEmpty()) {
         autoType()->performGlobalAutoType(unlockedDatabases);
     } else if (count() > 0) {
-        if (config()->get("security/relockautotype").toBool()) {
+        if (config()->get(Config::Security_RelockAutoType).toBool()) {
             m_dbWidgetPendingLock = currentDatabaseWidget();
         }
         unlockDatabaseInDialog(currentDatabaseWidget(), DatabaseOpenDialog::Intent::AutoType);
     }
 }
+
+void DatabaseTabWidget::performBrowserUnlock()
+{
+    auto dbWidget = currentDatabaseWidget();
+    if (dbWidget && dbWidget->isLocked()) {
+        unlockDatabaseInDialog(dbWidget, DatabaseOpenDialog::Intent::Browser);
+    }
+}
