@@ -29,7 +29,7 @@
 KeePass1OpenWidget::KeePass1OpenWidget(QWidget* parent)
     : DatabaseOpenWidget(parent)
 {
-    m_ui->labelHeadline->setText(tr("Import KeePass1 database"));
+    m_ui->labelHeadline->setText(tr("Import KeePass1 Database"));
 }
 
 void KeePass1OpenWidget::openDatabase()
@@ -37,16 +37,12 @@ void KeePass1OpenWidget::openDatabase()
     KeePass1Reader reader;
 
     QString password;
-    QString keyFileName;
+    QString keyFileName = m_ui->keyFileLineEdit->text();
 
-    if (m_ui->checkPassword->isChecked()) {
+    if (!m_ui->editPassword->text().isEmpty() || m_retryUnlockWithEmptyPassword) {
         password = m_ui->editPassword->text();
     }
 
-    if (m_ui->checkKeyFile->isChecked()) {
-        keyFileName = m_ui->comboKeyFile->currentText();
-    }
-
     QFile file(m_filename);
     if (!file.open(QIODevice::ReadOnly)) {
         m_ui->messageWidget->showMessage(tr("Unable to open the database.").append("\n").append(file.errorString()),
