@@ -118,6 +118,17 @@ MainWindow::MainWindow()
     m_searchWidgetAction = m_ui->toolBar->addWidget(m_searchWidget);
     m_searchWidgetAction->setEnabled(false);
 
+    new QShortcut(QKeySequence::Find, this, SLOT(focusSearchWidget()));
+
+    connect(m_searchWidget, &SearchWidget::searchCanceled, this, [this] {
+        m_ui->toolBar->setExpanded(false);
+        m_ui->toolBar->setVisible(!config()->get(Config::GUI_HideToolbar).toBool());
+    });
+    connect(m_searchWidget, &SearchWidget::lostFocus, this, [this] {
+        m_ui->toolBar->setExpanded(false);
+        m_ui->toolBar->setVisible(!config()->get(Config::GUI_HideToolbar).toBool());
+    });
+
     m_countDefaultAttributes = m_ui->menuEntryCopyAttribute->actions().size();
 
     m_entryContextMenu = new QMenu(this);
@@ -607,6 +618,19 @@ MainWindow::MainWindow()
     QObject::connect(qApp, SIGNAL(applicationActivated()), this, SLOT(bringToFront()));
     QObject::connect(qApp, SIGNAL(openFile(QString)), this, SLOT(openDatabase(QString)));
     QObject::connect(qApp, SIGNAL(quitSignalReceived()), this, SLOT(appExit()), Qt::DirectConnection);
+
+    statusBar()->setFixedHeight(24);
+    m_progressBarLabel = new QLabel(statusBar());
+    m_progressBarLabel->setVisible(false);
+    statusBar()->addPermanentWidget(m_progressBarLabel);
+    m_progressBar = new QProgressBar(statusBar());
+    m_progressBar->setVisible(false);
+    m_progressBar->setTextVisible(false);
+    m_progressBar->setMaximumWidth(100);
+    m_progressBar->setFixedHeight(15);
+    m_progressBar->setMaximum(100);
+    statusBar()->addPermanentWidget(m_progressBar);
+    connect(clipboard(), SIGNAL(updateCountdown(int, QString)), this, SLOT(updateProgressBar(int, QString)));
 }
 
 MainWindow::~MainWindow()
@@ -1214,7 +1238,10 @@ void MainWindow::keyPressEvent(QKeyEvent* event)
                 dbWidget->focusOnEntries(true);
                 return;
             } else if (event->key() == Qt::Key_F3) {
-                m_searchWidget->searchFocus();
+                focusSearchWidget();
+                return;
+            } else if (event->key() == Qt::Key_Escape && dbWidget->isSearchActive()) {
+                m_searchWidget->clearSearch();
                 return;
             }
         }
@@ -1235,13 +1262,13 @@ bool MainWindow::focusNextPrevChild(bool next)
             } else if (m_ui->tabWidget->hasFocus()) {
                 dbWidget->setFocus(Qt::TabFocusReason);
             } else {
-                m_searchWidget->setFocus(Qt::TabFocusReason);
+                focusSearchWidget();
             }
         } else {
             if (m_searchWidget->hasFocus()) {
                 dbWidget->setFocus(Qt::BacktabFocusReason);
             } else if (m_ui->tabWidget->hasFocus()) {
-                m_searchWidget->setFocus(Qt::BacktabFocusReason);
+                focusSearchWidget();
             } else {
                 m_ui->tabWidget->setFocus(Qt::BacktabFocusReason);
             }
@@ -1253,6 +1280,15 @@ bool MainWindow::focusNextPrevChild(bool next)
     return QMainWindow::focusNextPrevChild(next);
 }
 
+void MainWindow::focusSearchWidget()
+{
+    if (m_searchWidgetAction->isEnabled()) {
+        m_ui->toolBar->setVisible(true);
+        m_ui->toolBar->setExpanded(true);
+        m_searchWidget->focusSearch();
+    }
+}
+
 void MainWindow::saveWindowInformation()
 {
     if (isVisible()) {
@@ -1342,6 +1378,19 @@ void MainWindow::updateTrayIcon()
     QApplication::setQuitOnLastWindowClosed(!isTrayIconEnabled());
 }
 
+void MainWindow::updateProgressBar(int percentage, QString message)
+{
+    if (percentage < 0) {
+        m_progressBar->setVisible(false);
+        m_progressBarLabel->setVisible(false);
+    } else {
+        m_progressBar->setValue(percentage);
+        m_progressBar->setVisible(true);
+        m_progressBarLabel->setText(message);
+        m_progressBarLabel->setVisible(true);
+    }
+}
+
 void MainWindow::obtainContextFocusLock()
 {
     m_contextMenuFocusLock = true;
@@ -1773,6 +1822,7 @@ void MainWindow::initViewMenu()
     });
 
     connect(m_ui->actionAlwaysOnTop, &QAction::toggled, this, [this](bool checked) {
+        config()->set(Config::GUI_AlwaysOnTop, checked);
         if (checked) {
             setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
         } else {
@@ -1780,6 +1830,8 @@ void MainWindow::initViewMenu()
         }
         show();
     });
+    // Set checked after connecting to act on a toggle in state (default state is unchecked)
+    m_ui->actionAlwaysOnTop->setChecked(config()->get(Config::GUI_AlwaysOnTop).toBool());
 
     m_ui->actionHideUsernames->setChecked(config()->get(Config::GUI_HideUsernames).toBool());
     connect(m_ui->actionHideUsernames, &QAction::toggled, this, [](bool checked) {
