@@ -20,12 +20,16 @@
 #define KEEPASSX_MAINWINDOW_H
 
 #include <QActionGroup>
+#include <QLabel>
 #include <QMainWindow>
+#include <QProgressBar>
+#include <QStatusBar>
 #include <QSystemTrayIcon>
 
 #include "core/ScreenLockListener.h"
 #include "core/SignalMultiplexer.h"
 #include "gui/Application.h"
+#include "gui/Clipboard.h"
 #include "gui/DatabaseWidget.h"
 
 namespace Ui
@@ -138,6 +142,8 @@ private slots:
 
 private slots:
     void updateTrayIcon();
+    void updateProgressBar(int percentage, QString message);
+    void focusSearchWidget();
 
 private:
     static void setShortcut(QAction* action, QKeySequence::StandardKey standard, int fallback = 0);
@@ -169,6 +175,8 @@ private:
     QPointer<QSystemTrayIcon> m_trayIcon;
     QPointer<ScreenLockListener> m_screenLockListener;
     QPointer<SearchWidget> m_searchWidget;
+    QPointer<QProgressBar> m_progressBar;
+    QPointer<QLabel> m_progressBarLabel;
 
     Q_DISABLE_COPY(MainWindow)
 
