@@ -52,16 +52,19 @@ protected:
 
 signals:
     void search(const QString& text);
+    void searchCanceled();
     void caseSensitiveChanged(bool state);
     void limitGroupChanged(bool state);
     void escapePressed();
     void copyPressed();
     void downPressed();
     void enterPressed();
+    void lostFocus();
 
 public slots:
     void databaseChanged(DatabaseWidget* dbWidget = nullptr);
-    void searchFocus();
+    void focusSearch();
+    void clearSearch();
 
 private slots:
     void startSearchTimer();
