@@ -23,8 +23,7 @@
 
 #include "gui/MessageBox.h"
 
-
-CsvImportWizard::CsvImportWizard(QWidget *parent)
+CsvImportWizard::CsvImportWizard(QWidget* parent)
     : DialogyWidget(parent)
 {
     m_layout = new QGridLayout(this);
@@ -34,7 +33,8 @@ CsvImportWizard::CsvImportWizard(QWidget *parent)
 }
 
 CsvImportWizard::~CsvImportWizard()
-{}
+{
+}
 
 void CsvImportWizard::load(const QString& filename, Database* database)
 {
@@ -42,23 +42,6 @@ void CsvImportWizard::load(const QString& filename, Database* database)
     m_parse->load(filename, database);
 }
 
-void CsvImportWizard::keyFinished(bool accepted, CompositeKey key)
-{
-    if (!accepted) {
-        emit importFinished(false);
-        return;
-    }
-
-    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-    bool result = m_db->setKey(key);
-    QApplication::restoreOverrideCursor();
-
-    if (!result) {
-        MessageBox::critical(this, tr("Error"), tr("Unable to calculate master key"));
-        emit importFinished(false);
-    }
-}
-
 void CsvImportWizard::parseFinished(bool accepted)
 {
     emit importFinished(accepted);
