@@ -20,6 +20,7 @@
 
 #include <QComboBox>
 #include <QScopedPointer>
+#include <QScrollArea>
 
 #include "core/Group.h"
 #include "gui/EditWidget.h"
@@ -78,7 +79,7 @@ private:
 
     const QScopedPointer<Ui::EditGroupWidgetMain> m_mainUi;
 
-    QPointer<QWidget> m_editGroupWidgetMain;
+    QPointer<QScrollArea> m_editGroupWidgetMain;
     QPointer<EditWidgetIcons> m_editGroupWidgetIcons;
     QPointer<EditWidgetProperties> m_editWidgetProperties;
 
