@@ -25,8 +25,8 @@
 class AgentSettingsPage : public ISettingsPage
 {
 public:
-    AgentSettingsPage(DatabaseTabWidget* tabWidget);
-    ~AgentSettingsPage() override;
+    AgentSettingsPage() = default;
+    ~AgentSettingsPage() override = default;
 
     QString name() override;
     QIcon icon() override;
