@@ -28,7 +28,6 @@ class QUrl;
 
 namespace Totp
 {
-
     struct Encoder
     {
         QString name;
@@ -39,12 +38,26 @@ namespace Totp
         bool reverse;
     };
 
+    enum Algorithm
+    {
+        Sha1,
+        Sha256,
+        Sha512,
+    };
+
+    enum StorageFormat
+    {
+        OTPURL,
+        KEEOTP,
+        LEGACY,
+    };
+
     struct Settings
     {
+        Totp::StorageFormat format;
         Totp::Encoder encoder;
+        Totp::Algorithm algorithm;
         QString key;
-        bool otpUrl;
-        bool keeOtp;
         bool custom;
         uint digits;
         uint step;
@@ -53,6 +66,8 @@ namespace Totp
     constexpr uint DEFAULT_STEP = 30u;
     constexpr uint DEFAULT_DIGITS = 6u;
     constexpr uint STEAM_DIGITS = 5u;
+    constexpr Totp::Algorithm DEFAULT_ALGORITHM = Sha1;
+    constexpr Totp::StorageFormat DEFAULT_FORMAT = OTPURL;
     static const QString STEAM_SHORTNAME = "S";
 
     static const QString ATTRIBUTE_OTP = "otp";
@@ -63,8 +78,9 @@ namespace Totp
     QSharedPointer<Totp::Settings> createSettings(const QString& key,
                                                   const uint digits,
                                                   const uint step,
+                                                  const Totp::StorageFormat format = DEFAULT_FORMAT,
                                                   const QString& encoderShortName = {},
-                                                  QSharedPointer<Totp::Settings> prevSettings = {});
+                                                  const Totp::Algorithm algorithm = DEFAULT_ALGORITHM);
     QString writeSettings(const QSharedPointer<Totp::Settings>& settings,
                           const QString& title = {},
                           const QString& username = {},
@@ -72,6 +88,9 @@ namespace Totp
 
     QString generateTotp(const QSharedPointer<Totp::Settings>& settings, const quint64 time = 0ull);
 
+    QList<QPair<QString, QString>> supportedEncoders();
+    QList<QPair<QString, Algorithm>> supportedAlgorithms();
+
     Encoder& defaultEncoder();
     Encoder& steamEncoder();
     Encoder& getEncoderByShortName(const QString& shortName);
