@@ -35,6 +35,9 @@ private slots:
     void testSearch();
     void testAllAttributesAreSearched();
     void testSearchTermParser();
+    void testCustomAttributesAreSearched();
+    void testGroup();
+    void testSkipProtected();
 
 private:
     Group* m_rootGroup;
