@@ -45,6 +45,11 @@ private slots:
     void testIsRecycled();
     void testCopyDataFrom();
     void testEquals();
+    void testChildrenSort();
+    void testHierarchy();
+    void testApplyGroupIconRecursively();
+    void testUsernamesRecursive();
+    void testMove();
 };
 
 #endif // KEEPASSX_TESTGROUP_H
